Struct bexpand::Expression

source ·
pub struct Expression<'a>(_);
Bash-style brace expression. Can be created using TryFrom (like "foo{bar,baz}biz".try_into()) or via FromStr ("foo{bar,baz}biz".parse()). TryFrom is preferred, because it will avoid unnecessary allocations wherever possible, and tie to the lifetime of the incoming string. FromStr will make String clones in unnecessary places.